Create a Clojure wrapper over the UnleashSubscriber interface.
Create a Clojure wrapper over the UnleashSubscriber interface.
(build {:keys [on-error on-event on-ready toggle-evaluated toggles-fetched
client-metrics client-registered toggles-backed-up
toggle-backup-restored]
:or {on-error no-op
on-event no-op
toggle-evaluated no-op
toggles-fetched no-op
client-metrics no-op
client-registered no-op
toggles-backed-up no-op
toggle-backup-restored no-op}})Expects a map of event types to event handlers. Returns an instance of UnleashSubscriber which would be called when the internal state of the Unleash client changes. This instance can be attached to the Unleash client by using unleash-client-clojure.builder/subscriber.
Expects a map of event types to event handlers. Returns an instance of UnleashSubscriber which would be called when the internal state of the Unleash client changes. This instance can be attached to the Unleash client by using unleash-client-clojure.builder/subscriber.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |