(build & builder-param-setters)Expects to be applied with a variadic number of builder-setter functions. Returns an instance of DefaultUnleash that supports AppsFlyer-specific strategies.
Expects to be applied with a variadic number of builder-setter functions. Returns an instance of DefaultUnleash that supports AppsFlyer-specific strategies.
(build-with-custom-strategies strategies & builder-param-setters)Expects to be applied with a sequence of strategies and a variadic number of builder-setter functions. Returns an instance of DefaultUnleash that supports the provided strategies.
Expects to be applied with a sequence of strategies and a variadic number of builder-setter functions. Returns an instance of DefaultUnleash that supports the provided strategies.
An abstraction of an Unleash client.
An abstraction of an Unleash client.
(enabled? this toggle-name)(enabled? this toggle-name fallback)(enabled? this toggle-name context fallback)Returns 'true' whether the toggle is enabled, 'false' otherwise. Can also provide a custom fallback option in case the toggle isn't found via 'fallback', or a toggle evaluation context via 'context'.
Returns 'true' whether the toggle is enabled, 'false' otherwise. Can also provide a custom fallback option in case the toggle isn't found via 'fallback', or a toggle evaluation context via 'context'.
(get-feature-toggle-names this)Returns a sequence of all the feature toggles' names known to this client.
Returns a sequence of all the feature toggles' names known to this client.
(get-toggle-definition this toggle-name)Returns a toggle's definition.
Returns a toggle's definition.
(get-variant this toggle-name)(get-variant this toggle-name default-variant)Returns the instance's variant, useful for unit tests.
Returns the instance's variant, useful for unit tests.
(get-variant-with-context this toggle-name context)(get-variant-with-context this toggle-name context default-variant)Returns the instance's variant while evaluating the supplied context, useful for unit tests.
Returns the instance's variant while evaluating the supplied context, useful for unit tests.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |