unleash-client-clojure.variant


IVariantcljprotocol

A protocol to bridge the Java class no.finn.unleash.Variant into Clojure. The class is used in unit tests to change the state of a FakeUnleash instance.

A protocol to bridge the Java class no.finn.unleash.Variant into Clojure.
The class is used in unit tests to change the state of a FakeUnleash instance.

get-nameclj

(get-name this)

Returns the variant's name.

Returns the variant's name.

get-typeclj

(get-type this)

Returns the variant's type if it's present and the variant is enabled, otherwise returns nil.

Returns the variant's type if it's present and the variant is enabled, otherwise returns nil.

get-valueclj

(get-value this)

Returns the variant's value, if present, otherwise returns nil.

Returns the variant's value, if present, otherwise returns nil.

payloadclj

(payload this)

Returns the variant's payload, if it's present and the variant is enabled, otherwise returns nil.

Returns the variant's payload, if it's present and the variant is enabled, otherwise returns nil.

variant-enabled?clj

(variant-enabled? this)

Returns whether the variant is active or not.

Returns whether the variant is active or not.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries