A protocol to bridge the Java class no.finn.unleash.Variant into Clojure. The class is used in unit tests to change the state of a FakeUnleash instance.
A protocol to bridge the Java class no.finn.unleash.Variant into Clojure. The class is used in unit tests to change the state of a FakeUnleash instance.
(get-name this)Returns the variant's name.
Returns the variant's name.
(get-type this)Returns the variant's type if it's present and the variant is enabled, otherwise returns nil.
Returns the variant's type if it's present and the variant is enabled, otherwise returns nil.
(get-value this)Returns the variant's value, if present, otherwise returns nil.
Returns the variant's value, if present, otherwise returns nil.
(payload this)Returns the variant's payload, if it's present and the variant is enabled, otherwise returns nil.
Returns the variant's payload, if it's present and the variant is enabled, otherwise returns nil.
(variant-enabled? this)Returns whether the variant is active or not.
Returns whether the variant is active or not.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |